@@ -118,6 +118,7 @@ struct index_mail_data {
 	bool save_body_snippet:1;
 	bool stream_has_only_header:1;
 	bool parsed_bodystructure:1;
+	bool parsed_bodystructure_header:1;
 	bool hdr_size_set:1;
 	bool body_size_set:1;
 	bool messageparts_saved_to_cache:1;
@@ -129,6 +130,9 @@ struct index_mail_data {
 	bool destroy_callback_set:1;
 	bool prefetch_sent:1;
 	bool header_parser_initialized:1;
+	/* virtual_size and physical_size may not match the stream size.
+	   Try to avoid trusting them too much. */
+	bool inexact_total_sizes:1;
 };
 
 struct index_mail {
@@ -256,6 +260,7 @@ bool index_mail_get_cached_bodystructure(struct index_mail *mail,
 					 const char **value_r);
 const uint32_t *index_mail_get_vsize_extension(struct mail *_mail);
 
+bool index_mail_want_cache(struct index_mail *mail, enum index_cache_field field);
 void index_mail_cache_add(struct index_mail *mail, enum index_cache_field field,
 			  const void *data, size_t data_size);
 void index_mail_cache_add_idx(struct index_mail *mail, unsigned int field_idx,
